pub enum TokenError {
RefreshFailed(String),
ObtainFailed {
attempts: u32,
last_error: String,
},
RateLimited {
retry_after_seconds: u64,
},
Timeout {
timeout_seconds: u64,
},
Serialization(String),
Storage(String),
Validation(String),
}Expand description
Detailed error types for token management operations
Variants
RefreshFailed(String)
ObtainFailed
RateLimited
Timeout
Serialization(String)
Storage(String)
Validation(String)
Implementations
Sourceimpl TokenError
impl TokenError
Sourcepub fn refresh_failed<S: Into<String>>(message: S) -> Self
pub fn refresh_failed<S: Into<String>>(message: S) -> Self
Creates a new RefreshFailed error
Sourcepub const fn obtain_failed(attempts: u32, last_error: String) -> Self
pub const fn obtain_failed(attempts: u32, last_error: String) -> Self
Creates a new ObtainFailed error
Sourcepub const fn rate_limited(retry_after_seconds: u64) -> Self
pub const fn rate_limited(retry_after_seconds: u64) -> Self
Creates a new RateLimited error
Sourcepub fn serialization<S: Into<String>>(message: S) -> Self
pub fn serialization<S: Into<String>>(message: S) -> Self
Creates a new Serialization error
Sourcepub fn validation<S: Into<String>>(message: S) -> Self
pub fn validation<S: Into<String>>(message: S) -> Self
Creates a new Validation error
Sourcepub const fn is_retryable(&self) -> bool
pub const fn is_retryable(&self) -> bool
Returns true if this error indicates a retryable condition
Sourcepub const fn is_rate_limited(&self) -> bool
pub const fn is_rate_limited(&self) -> bool
Returns true if this error indicates a rate limiting condition
Sourcepub const fn retry_after_seconds(&self) -> Option<u64>
pub const fn retry_after_seconds(&self) -> Option<u64>
Returns the retry delay in seconds if this is a rate limited error