pub struct MockTokenStrategy { /* private fields */ }Expand description
Mock token strategy for isolated testing without persistence
Implementations
Sourceimpl MockTokenStrategy
impl MockTokenStrategy
Sourcepub const fn new(token: String) -> Self
pub const fn new(token: String) -> Self
Creates a new mock token strategy with the provided token
Sourcepub fn with_default_token() -> Self
pub fn with_default_token() -> Self
Creates a mock token strategy with a default test token