pub struct RegisterAssetResponse {
pub success: bool,
pub message: Option<String>,
pub asset_data: Option<Asset>,
}Expand description
Response from asset registration with the Blockstream Asset Registry Response from asset registration with the Blockstream Asset Registry
Fields
success: boolIndicates whether the registration was successful
message: Option<String>Optional message providing additional context
asset_data: Option<Asset>The full asset data if registration was successful (HTTP 200 with asset data)